==> data_fixtures-8.x-1.0-rc2.tar.gz: data_fixtures/src/Services/DummyGenerator.php <==
<?php

namespace Drupal\data_fixtures\Services;

class DummyGenerator {
  /**
   * @var array
   */
  private $titles = [
    'Lorem ipsum dolor sit amet',
    'Et ille ridens: Video, inquit, quid agas',
    'Hoc ille tuus',
    'Collige omnia, quae soletis',
    'Hoc est non modo cor non habere',
    'Quo studio Aristophanem putamus aetatem in litteris duxisse',
    'Duo Reges: constructio interrete',
  ];

  /**
   * @var array
   */
  private $urls = [
    'https://en.wikipedia.org/',
    'https://www.mozilla.org/en-US/firefox/new/',
    'https://www.openstreetmap.org/',
    'https://opensource.com/',
    'https://github.com/',
  ];

  private $attachments = [
    'sample.pdf',
  ];

  private $images = [
    'media' => ['dummy-media.jpg'],
    'mediaFull' => ['dummy-media-full.jpg'],
  ];

  /**
   * @var array
   */
  private $vimeoIds = [
    '3612941', // Nine Inch Nails: The perfect drug
    '61677369', // Nine Inch Nails: The becoming (still)
    '61997410', // Nine Inch Nails: Only
    '76227718', // On the job
    '33172663', // Lôzane’s Burning VI - MONKEY3
    '40368825', // Eluveitie - Thousandfold
    '36197258', // Nostromo Acoustique
    '52942657', // Dragon baby
    '76227718', // On the job
    '88630748', // Tiangmenshan Shaolin Kung Fu Academy
    '13133379', // LaRoux - Bulletproof (MNI asked for !)
    '174544848', // Geist
  ];

  /**
   * Create a random text from lorem ipsum generator.
   * It can be used for body, description, ...
   * @return string
   */
  public function getText() {
    $rand = $this->getRandom();
    $body = simplexml_load_file(
      'http://www.lipsum.com/feed/xml?amount=' . $rand . '&what=paras&start=0'
    )->lipsum;

    return $body;
  }

  /**
   * Create a random title.
   * @param int $maxLength The max length of the string to return
   * @return string
   */
  public function getTitle($maxLength=255) {
    return substr($this->titles[$this->getRandomIndex($this->titles)], 0, $maxLength);
  }

  /**
   * @param string $type
   * Get a random image.
   * @return string
   */
  public function getImage($type='media') {
    return $this->getModuleAssetsDirectory() . '/images/' . $this->images[$type][$this->getRandomIndex($this->images[$type])];
  }

  /**
   * Get a random vimeo's video.
   * @return string
   */
  public function getVimeoUrl() {
    return 'http://www.vimeo.com/' . $this->vimeoIds[$this->getRandomIndex
    (
      $this->vimeoIds
    )];
  }

  /**
   * Get a random url.
   * @return string
   */
  public function getUrl() {
    return $this->urls[$this->getRandomIndex($this->urls)];
  }

  /**
   * Get a random file.
   * @return mixed
   */
  public function getFile() {

    return $this->getModuleAssetsDirectory() . '/attachments/' . $this->attachments[$this->getRandomIndex($this->attachments)];
  }

  /**
   * @return string
   */
  private function getModuleAssetsDirectory() {
    return drupal_get_path('module', 'data_fixtures') . '/assets';
  }

  /**
   * Get a random number between 0-10.
   * @return integer
   */
  private function getRandom() {
    return rand(0, 10);
  }

  /**
   * Get random index on array
   * @param array $arr
   * @return integer
   */
  public function getRandomIndex(Array $arr) {
    return rand(0, count($arr) - 1);
  }
}

==> data_fixtures-8.x-1.2.tar.gz: data_fixtures/src/Services/DummyGenerator.php <==
<?php

namespace Drupal\data_fixtures\Services;

class DummyGenerator {
  /**
   * @var array
   */
  private $titles = [
    'Lorem ipsum dolor sit amet',
    'Et ille ridens: Video, inquit, quid agas',
    'Hoc ille tuus',
    'Collige omnia, quae soletis',
    'Hoc est non modo cor non habere',
    'Quo studio Aristophanem putamus aetatem in litteris duxisse',
    'Duo Reges: constructio interrete',
  ];

  /**
   * @var array
   */
  private $urls = [
    'https://en.wikipedia.org/',
    'https://www.mozilla.org/en-US/firefox/new/',
    'https://www.openstreetmap.org/',
    'https://opensource.com/',
    'https://github.com/',
  ];

  private $attachments = [
    'sample.pdf',
  ];

  private $images = [
    'media' => ['dummy-media.jpg'],
    'mediaFull' => ['dummy-media-full.jpg'],
  ];

  /**
   * @var array
   */
  private $vimeoIds = [
    '3612941', // Nine Inch Nails: The perfect drug
    '61677369', // Nine Inch Nails: The becoming (still)
    '61997410', // Nine Inch Nails: Only
    '76227718', // On the job
    '33172663', // Lôzane’s Burning VI - MONKEY3
    '40368825', // Eluveitie - Thousandfold
    '36197258', // Nostromo Acoustique
    '52942657', // Dragon baby
    '76227718', // On the job
    '88630748', // Tiangmenshan Shaolin Kung Fu Academy
    '13133379', // LaRoux - Bulletproof (MNI asked for !)
    '174544848', // Geist
  ];

  /**
   * @var string
   */
  private $text;

  /**
   * Create a random text from lorem ipsum generator.
   * It can be used for body, description, ...
   *
   * @param int $limit
   *
   * @return string
   */
  public function getText($limit = 100) {
    if (!$this->text) {
      $this->text = simplexml_load_file(
        'http://www.lipsum.com/feed/xml?amount=20&what=paras&start=0'
      )->lipsum;
    }

    $randomIndex = rand($limit, strlen($this->text));

    return substr($this->text, $randomIndex-$limit, $limit);
  }

  /**
   * Create a random title.
   * @param int $maxLength The max length of the string to return
   * @return string
   */
  public function getTitle($maxLength=255) {
    return substr($this->titles[$this->getRandomIndex($this->titles)], 0, $maxLength);
  }

  /**
   * @param string $type
   * Get a random image.
   * @return string
   */
  public function getImage($type='media') {
    return $this->getModuleAssetsDirectory() . '/images/' . $this->images[$type][$this->getRandomIndex($this->images[$type])];
  }

  /**
   * Get a random vimeo's video.
   * @return string
   */
  public function getVimeoUrl() {
    return 'http://www.vimeo.com/' . $this->vimeoIds[$this->getRandomIndex
      (
        $this->vimeoIds
      )];
  }

  /**
   * Get a random url.
   * @return string
   */
  public function getUrl() {
    return $this->urls[$this->getRandomIndex($this->urls)];
  }

  /**
   * Get a random file.
   * @return mixed
   */
  public function getFile() {

    return $this->getModuleAssetsDirectory() . '/attachments/' . $this->attachments[$this->getRandomIndex($this->attachments)];
  }

  /**
   * @return string
   */
  private function getModuleAssetsDirectory() {
    return drupal_get_path('module', 'data_fixtures') . '/assets';
  }

  /**
   * Get a random number between 0-10.
   * @return integer
   */
  private function getRandom() {
    return rand(0, 10);
  }

  /**
   * Get random index on array
   * @param array $arr
   * @return integer
   */
  public function getRandomIndex(Array $arr) {
    return rand(0, count($arr) - 1);
  }
}
